.. _math:

Mathematics
===========

:code:`stylo` tries its best to be usable without requiring you to be a mathematician.
However by making use of mathematical ideas and concepts throughout there will inevitably
come a point where you will benefit from at least some knowledge on the mathematics going
on behind the code.

This section of the documentation aims to at least introduce to some of the concepts at
play, how they relate to :code:`stylo` itself and if you wish to dig deeper where you can
go to find out more.

.. toctree::
   :maxdepth: 2

   numbers
   cartesian-coordinates
   polar-coordinates
